/* ISC license. */

/* Generated by: ./configure --prefix=/usr --sysconfdir=/etc --disable-static --enable-pkgconfig --enable-shared --with-pkgconfig */

#ifndef SKALIBS_CONFIG_H
#define SKALIBS_CONFIG_H

#define SKALIBS_VERSION "2.15.0.0"
#define SKALIBS_DEFAULTPATH "/usr/bin:/bin"
#define SKALIBS_ETC "/etc"
#define SKALIBS_SPROOT ""
#define SKALIBS_HOME ""
#undef SKALIBS_FLAG_CLOCKISTAI
#define SKALIBS_FLAG_WANTIPV6
#undef SKALIBS_FLAG_PREFERSELECT

#endif
